
// HideText.java
// Andrew Davison, May 2009, ad@fivedots.coe.psu.ac.th

/* A test rig for the steganography hide() method which hides 
   a text file in a PNG file, creating a new image whose name
   ends with ...Msg.png

   Depending on the steg type number supplied by the user, 
   one of four possible steganography classes is used.
     0 == Steganography class
     1 == StegCrypt class
     2 == MultiStegCrypt class
     3 == FragMultiStegCrypt class

   Usage: run HideText <steg type number> <text file> <PNG file>
   e.g.
     run HideText 3 examps\Comparison.java  images\waterlilies.png
            // generates images\waterliliesMsg.png  using FragMultiStegCrypt
*/

public class HideText
{
  public static void main(String[] args)
  {
    if (args.length != 3)
      System.out.println("Usage: java HideText <steg type> <text file> <image file>");
    else {
      int stegType = getNumber(args[0]);
      switch(stegType) {
        case 1:
          System.out.println("Using StegCrypt...");
          StegCrypt.hide(args[1], args[2]);
          break;
        case 2:
          System.out.println("Using MultiStegCrypt...");
          MultiStegCrypt.hide(args[1], args[2]);
          break;
        case 3:
          System.out.println("Using FragMultiStegCrypt...");
          FragMultiStegCrypt.hide(args[1], args[2]);
          break;
        default:
          System.out.println("Using basic Steganography...");
          Steganography.hide(args[1], args[2]);
          break;
      } // end switch
    }
  }  // end of main()


  private static int getNumber(String str)
  {
    int val = 0;
    try { 
      val = Integer.parseInt(str); 
    } 
    catch (NumberFormatException e)
    { System.out.println("Could not parse number: \"" + str + "\""); }

    return val;
  }  // end of getNumber()


}  // end of HideText class