
// RevealText.java
// Andrew Davison, May 2009, ad@fivedots.coe.psu.ac.th

/* A test rig for the steganography reveal() method which extracts 
   a message from a PNG file, creating a new text file.

   Depending on the steg type number supplied by the user, 
   one of four possible steganography classes is used.
     0 == Steganography class
     1 == StegCrypt class
     2 == MultiStegCrypt class
     3 == FragMultiStegCrypt class

   Usage: RevealText <steg type number> <PNG file>
   e.g.
     run RevealText 3 images\waterlilliesMsg.png
       // generates images\waterlilliesMsg.txt  using FragMultiStegCrypt

*/


public class RevealText
{
  public static void main(String[] args)
  {
    if (args.length != 2)
      System.out.println("Usage: java RevealText <steg type> <image file>");
    else {
      int stegType = getNumber(args[0]);
      switch(stegType) {
        case 1:
          System.out.println("Using StegCrypt...");
          StegCrypt.reveal(args[1]);
          break;
        case 2:
          System.out.println("Using MultiStegCrypt...");
          MultiStegCrypt.reveal(args[1]);
          break;
        case 3:
          System.out.println("Using FragMultiStegCrypt...");
          FragMultiStegCrypt.reveal(args[1]);
          break;
        default:
          System.out.println("Using basic Steganography...");
          Steganography.reveal(args[1]);
          break;
      } // end switch
    }
  }  // end of main()


  private static int getNumber(String str)
  {
    int val = 0;
    try { 
      val = Integer.parseInt(str); 
    } 
    catch (NumberFormatException e)
    { System.out.println("Could not parse number: \"" + str + "\""); }

    return val;
  }  // end of getNumber()


}  // end of RevealText class